About
-----

PyRAMSES is Python module that facilitates the use of the dynamic simulator RAMSES. 
The module provides basic functionality like defining test-cases, running simulation,
extracting information, etc. As well as more advance integration of the simulator into 
the remaining Python code.

Please check the documentation under `https://ramses.paristidou.info <https://ramses.paristidou.info>`_.